@@ -70,6 +70,11 @@ func TestIntegration(t *testing.T) {
 			Command: "./tflint --chdir=dir --format json --fix",
 			Dir:     "chdir",
 		},
+		{
+			Name:    "--chdir with conflict",
+			Command: "./tflint --chdir=dir --format json --fix",
+			Dir:     "chdir_with_conflict",
+		},
 		{
 			Name:    "--filter",
 			Command: "./tflint --format json --fix --filter=main.tf",
