@@ -4,6 +4,7 @@ import (
 	"errors"
 	"fmt"
 	"log"
+	"sync"
 
 	"github.com/hashicorp/go-version"
 	hcl "github.com/hashicorp/hcl/v2"
@@ -17,6 +18,7 @@ import (
 
 // GRPCServer is a gRPC server for responding to requests from plugins.
 type GRPCServer struct {
+	mu               sync.Mutex
 	runner           *tflint.Runner
 	rootRunner       *tflint.Runner
 	files            map[string]*hcl.File
@@ -50,6 +52,8 @@ func (s *GRPCServer) GetModuleContent(bodyS *hclext.BodySchema, opts sdk.GetModu
 		module = s.runner.TFConfig.Module
 		ctx = s.runner.Ctx
 	case sdk.RootModuleCtxType:
+		s.mu.Lock()
+		defer s.mu.Unlock()
 		module = s.rootRunner.TFConfig.Module
 		ctx = s.rootRunner.Ctx
 	default:
@@ -87,6 +91,8 @@ func (s *GRPCServer) GetFiles(ty sdk.ModuleCtxType) map[string][]byte {
 	case sdk.SelfModuleCtxType:
 		return s.runner.Sources()
 	case sdk.RootModuleCtxType:
+		// HINT: This is an operation on the root runner,
+		//       but it works without locking since it is obviously readonly.
 		return s.rootRunner.Sources()
 	default:
 		panic(fmt.Sprintf("invalid ModuleCtxType: %s", ty))
@@ -127,6 +133,8 @@ func (s *GRPCServer) EvaluateExpr(expr hcl.Expression, opts sdk.EvaluateExprOpti
 	case sdk.SelfModuleCtxType:
 		runner = s.runner
 	case sdk.RootModuleCtxType:
+		s.mu.Lock()
+		defer s.mu.Unlock()
 		runner = s.rootRunner
 	}
 
@@ -188,6 +196,9 @@ func (s *GRPCServer) EvaluateExpr(expr hcl.Expression, opts sdk.EvaluateExprOpti
 }
 
 // EmitIssue stores an issue in the server based on passed rule, message, and location.
+// It attempts to detect whether the issue range represents an expression and emits it based on that context.
+// However, some ranges may be syntactically valid but not actually represent an expression.
+// In these cases, the "expression" is still provided as context and the client should ignore any errors when attempting to evaluate it.
 func (s *GRPCServer) EmitIssue(rule sdk.Rule, message string, location hcl.Range, fixable bool) (bool, error) {
 	// If the issue range represents an expression, it is emitted based on that context.
 	// This is required to emit issues in called modules.
